# Licensed under a 3-clause BSD style license - see LICENSE.rst
"""
This packages contains affiliated package tests.
"""

import numpy as np

from .. import CustomType


class CustomTestType(CustomType):
    """This class is intended to be inherited by custom types that are used
    purely for the purposes of testing. The methods ``from_tree_tagged`` and
    ``from_tree`` are implemented solely in order to avoid custom type
    conversion warnings.
    """

    @classmethod
    def from_tree_tagged(cls, tree, ctx):
        return cls.from_tree(tree.data, ctx)

    @classmethod
    def from_tree(cls, tree, ctx):
        return tree


def create_small_tree():
    x = np.arange(0, 10, dtype=np.float)
    tree = {
        'science_data': x,
        'subset': x[3:-3],
        'skipping': x[::2],
        'not_shared': np.arange(10, 0, -1, dtype=np.uint8)
    }
    return tree


def create_large_tree():
    # These are designed to be big enough so they don't fit in a
    # single block, but not so big that RAM/disk space for the tests
    # is enormous.
    x = np.random.rand(256, 256)
    y = np.random.rand(16, 16, 16)
    tree = {
        'science_data': x,
        'more': y
    }
    return tree
